@@ -181,15 +181,15 @@ where
 
     #[cfg(target_os = "windows")]
     async fn command_execution(&mut self) -> Result<S, E> {
-        let (sender, receiver) = tokio::sync::mpsc::channel::<LogOutputData>(1000);
-        let res = self.run_process().await;
-        let stdout = self.process.stdout.take().unwrap();
         //TODO: find another way to use stderr on windows
+        // let (sender, receiver) = tokio::sync::mpsc::channel::<LogOutputData>(1000);
+        let res = self.run_process().await;
+        // let stdout = self.process.stdout.take().unwrap();
         // let stderr = self.process.stderr.take().unwrap();
-        let tx = sender.clone();
-        let _ = tokio::task::spawn(async { Self::handle_output(stdout, tx).await });
+        // let tx = sender.clone();
+        // let _ = tokio::task::spawn(async { Self::handle_output(stdout, tx).await });
         // let _ = tokio::task::spawn(async { Self::handle_output(stderr, sender).await });
-        let _ = tokio::task::spawn(async { Self::log_output(receiver).await });
+        // let _ = tokio::task::spawn(async { Self::log_output(receiver).await });
         res
     }
 
